@@ -1,18 +1,18 @@
-__version__ = "4.0.3"
+__version__ = "4.0.6"
 
 __authors__ = [
-    'Juanmi Taboada',
-    'Juan Soler Ruiz',
+    "Juanmi Taboada",
+    "Juan Soler Ruiz",
 ]
 
 __authors_email__ = [
-    'juanmi@juanmitaboada.com',
-    'soleronline@gmail.com',
+    "juanmi@juanmitaboada.com",
+    "soleronline@gmail.com",
 ]
 
 
 __requirements__ = {
-    'all': [
+    "all": [
         "pymongo",
         "python-dateutil",
         "django-recaptcha>=1.2.1,<1.3",
@@ -27,11 +27,12 @@ __requirements__ = {
         "pytz",
         "elasticsearch>=2.0.0,<3.0.0",
         "django-debug-toolbar==3.2.2",
+        "pyotp",
     ],
-    '2': [
+    "2": [
         "html5lib==1.0b8",  # Default version 0.99999999 is broken with error 'from html5lib import treebuilders, inputstream' => 'ImportError: cannot import name inputstream' (1.0b10 also fails)
     ],
-    '3': [
+    "3": [
         "html5lib",
     ],
 }
